@@ -30,7 +30,12 @@ struct media_transport *media_transport_create(DBusConnection *conn,
 						uint8_t *configuration,
 						size_t size);
 
-void media_transport_remove(struct media_transport *transport);
+void media_transport_destroy(struct media_transport *transport);
 const char *media_transport_get_path(struct media_transport *transport);
+struct audio_device *media_transport_get_dev(struct media_transport *transport);
 void media_transport_update_delay(struct media_transport *transport,
 							uint16_t delay);
+void media_transport_update_volume(struct media_transport *transport,
+								uint8_t volume);
+void transport_get_properties(struct media_transport *transport,
+							DBusMessageIter *iter);
