@@ -33,14 +33,12 @@
 #include "adapter.h"
 #include "device.h"
 #include "att.h"
+#include "gattrib.h"
+#include "gatt.h"
 #include "monitor.h"
 #include "reporter.h"
 #include "manager.h"
 
-#define IMMEDIATE_ALERT_UUID	"00001802-0000-1000-8000-00805f9b34fb"
-#define LINK_LOSS_UUID		"00001803-0000-1000-8000-00805f9b34fb"
-#define TX_POWER_UUID		"00001804-0000-1000-8000-00805f9b34fb"
-
 static DBusConnection *connection = NULL;
 
 static struct enabled enabled  = {
@@ -51,7 +49,7 @@ static struct enabled enabled  = {
 
 static gint primary_uuid_cmp(gconstpointer a, gconstpointer b)
 {
-	const struct att_primary *prim = a;
+	const struct gatt_primary *prim = a;
 	const char *uuid = b;
 
 	return g_strcmp0(prim->uuid, uuid);
@@ -59,7 +57,7 @@ static gint primary_uuid_cmp(gconstpointer a, gconstpointer b)
 
 static int attio_device_probe(struct btd_device *device, GSList *uuids)
 {
-	struct att_primary *linkloss, *txpower, *immediate;
+	struct gatt_primary *linkloss, *txpower, *immediate;
 	GSList *l, *primaries;
 
 	primaries = btd_device_get_primaries(device);
@@ -84,12 +82,18 @@ static void attio_device_remove(struct btd_device *device)
 }
 
 static struct btd_device_driver monitor_driver = {
-	.name = "Proximity GATT Driver",
+	.name = "Proximity GATT Monitor Driver",
 	.uuids = BTD_UUIDS(IMMEDIATE_ALERT_UUID, LINK_LOSS_UUID, TX_POWER_UUID),
 	.probe = attio_device_probe,
 	.remove = attio_device_remove,
 };
 
+static struct btd_adapter_driver reporter_server_driver = {
+	.name = "Proximity GATT Reporter Driver",
+	.probe = reporter_init,
+	.remove = reporter_exit,
+};
+
 static void load_config_file(GKeyFile *config)
 {
 	char **list;
@@ -118,19 +122,29 @@ int proximity_manager_init(DBusConnection *conn, GKeyFile *config)
 
 	load_config_file(config);
 
-	/* TODO: Register Proximity Monitor/Reporter drivers */
-	ret = btd_register_device_driver(&monitor_driver);
-	if (ret < 0)
-		return ret;
-
 	connection = dbus_connection_ref(conn);
 
-	return reporter_init();
+	ret = btd_register_device_driver(&monitor_driver);
+	if (ret < 0)
+		goto fail_monitor;
+
+	ret = btd_register_adapter_driver(&reporter_server_driver);
+	if (ret < 0)
+		goto fail_reporter;
+
+	return 0;
+
+fail_reporter:
+	btd_unregister_device_driver(&monitor_driver);
+
+fail_monitor:
+	dbus_connection_unref(connection);
+	return ret;
 }
 
 void proximity_manager_exit(void)
 {
-	reporter_exit();
 	btd_unregister_device_driver(&monitor_driver);
+	btd_unregister_adapter_driver(&reporter_server_driver);
 	dbus_connection_unref(connection);
 }
